@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client;
 # ABSTRACT: A comprehensive, DWIM-featured client to the MetaCPAN API
-$MetaCPAN::Client::VERSION = '2.019000';
+$MetaCPAN::Client::VERSION = '2.020000';
 use Moo;
 use Carp;
 use Ref::Util qw< is_arrayref is_hashref >;
@@ -216,6 +216,24 @@ sub autocomplete {
     ];
 }
 
+sub autocomplete_suggest {
+    my $self = shift;
+    my $q    = shift;
+
+    my $res;
+
+    eval {
+        $res = $self->fetch( '/search/autocomplete/suggest?q=' . uri_escape_utf8($q) );
+        1;
+
+    } or do {
+        warn $@;
+        return [];
+    };
+
+    return $res->{suggestions};
+}
+
 ###
 
 sub _get {
@@ -394,7 +412,7 @@ MetaCPAN::Client - A comprehensive, DWIM-featured client to the MetaCPAN API
 
 =head1 VERSION
 
-version 2.019000
+version 2.020000
 
 =head1 SYNOPSIS
 
@@ -561,6 +579,14 @@ Call the search/autocomplete endpoint with a query string.
 
 Returns an array reference.
 
+=head2 autocomplete_suggest
+
+    my $ac = $mcpan->autocomplete_suggest('Moo');
+
+Call the search/autocomplete/suggest endpoint with a query string.
+
+Returns an array reference.
+
 =head2 recent
 
     my $recent = $mcpan->recent(10);
